//-----------------------------------------------------------------------------
/** @file libboardgame_base/Transform.cpp
    @author Markus Enzenberger
    @copyright GNU General Public License version 3 or later */
//-----------------------------------------------------------------------------

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "Transform.h"

namespace libboardgame_base {

//-----------------------------------------------------------------------------

Transform::~Transform() = default;

//-----------------------------------------------------------------------------

} // namespace libboardgame_base
